@@ -52,7 +52,7 @@ def subtract(value, amount):
 def has_charts(group):
     from sentry.utils.db import has_charts
     if hasattr(group, '_state'):
-        db = group._state.db
+        db = group._state.db or 'default'
     else:
         db = 'default'
     return has_charts(db)
@@ -271,17 +271,22 @@ def date(datetime, arg=None):
                 Constant('from'), Variable('project'),
                 Constant('as'), Name('asvar')])
 def get_project_dsn(context, user, project, asvar):
-    from sentry.models import ProjectMember
+    from sentry.models import ProjectKey
 
     if not user.is_authenticated():
         context[asvar] = None
         return ''
 
     try:
-        member = ProjectMember.objects.get(user=user, project=project)
-    except ProjectMember.DoesNotExist:
-        context[asvar] = None
+        key = ProjectKey.objects.get(user=user, project=project)
+    except ProjectKey.DoesNotExist:
+        try:
+            key = ProjectKey.objects.filter(user=None, project=project)[0]
+        except IndexError:
+            context[asvar] = None
+        else:
+            context[asvar] = key.get_dsn()
     else:
-        context[asvar] = member.get_dsn()
+        context[asvar] = key.get_dsn()
 
     return ''
